@@ -18,7 +18,7 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from qt import usingQt5, Qt, QPointF, QPoint, QRectF, QMimeData, QSize, QVariant
+from qt import variantValue, Qt, QPointF, QPoint, QRectF, QMimeData, QSize, toQVariant
 from qt import QGraphicsRectItem, QGraphicsItem, QSizePolicy, QFrame, QFont
 from qt import QGraphicsView, QGraphicsEllipseItem, QLabel
 from qt import QColor, QPainter, QDrag, QPixmap, QStyleOptionGraphicsItem, QPen, QBrush
@@ -30,17 +30,19 @@ from tile import Tile, elements
 from uitile import UITile, UIMeld
 from guiutil import Painter
 from meld import Meld
-from animation import Animation, Animated, animate
+from animation import Animation, MoveImmediate, animate
 from message import Message
 
 from util import kprint, stack, uniqueList
 from log import logDebug, logException, m18n, m18nc
-from common import WINDS, LIGHTSOURCES, Internal, Debug, isAlive
+from common import LIGHTSOURCES, Internal, Debug, isAlive, unicode
+from wind import Wind, East
 
 ROUNDWINDCOLOR = QColor(235, 235, 173)
 
 WINDPIXMAPS = {}
 
+
 def rotateCenter(item, angle):
     """rotates a QGraphicsItem around its center"""
     center = item.boundingRect().center()
@@ -49,12 +51,16 @@ def rotateCenter(item, angle):
         centerX, centerY).rotate(angle).translate(-centerX, -centerY))
     return item
 
+
 class PlayerWind(QGraphicsEllipseItem):
+
     """a round wind tile"""
+
     def __init__(self, name, tileset, roundsFinished=0, parent=None):
         """generate new wind tile"""
+        assert isinstance(name, Wind), 'PlayerWind expects Wind, not {}'.format(type(name))
         if not len(WINDPIXMAPS):
-            WINDPIXMAPS[('E', False)] = None # avoid recursion
+            WINDPIXMAPS[(East, False)] = None  # avoid recursion
             self.genWINDPIXMAPS()
         QGraphicsEllipseItem.__init__(self)
         if parent:
@@ -71,7 +77,7 @@ class PlayerWind(QGraphicsEllipseItem):
     def genWINDPIXMAPS():
         """prepare wind tiles"""
         tileset = Tileset(Internal.Preferences.windTilesetName)
-        for wind in WINDS:
+        for wind in Wind.all4:
             for prevailing in False, True:
                 pwind = PlayerWind(wind, tileset, prevailing)
                 pMap = QPixmap(40, 40)
@@ -94,8 +100,8 @@ class PlayerWind(QGraphicsEllipseItem):
         self.setFlag(QGraphicsItem.ItemClipsChildrenToShape)
         diameter = size.height() * 1.1
         scaleFactor = 0.9
-        facePos = {'traditional':(10, 10), 'default':(15, 10),
-                   'classic':(19, 1), 'jade':(19, 1)}
+        facePos = {'traditional': (10, 10), 'default': (15, 10),
+                   'classic': (19, 1), 'jade': (19, 1)}
         self.setRect(0, 0, diameter, diameter)
         self.setScale(scaleFactor)
         faceX, faceY = facePos[self.tileset.desktopFileName]
@@ -104,16 +110,19 @@ class PlayerWind(QGraphicsEllipseItem):
 
     def setWind(self, name, roundsFinished):
         """change the wind"""
+        assert isinstance(name, Wind) and name.svgName, 'name {}  must be a real Wind but is {}'.format(
+            name, type(name))
         self.name = name
         if isinstance(roundsFinished, bool):
             self.prevailing = roundsFinished
         else:
-            self.prevailing = name == WINDS[roundsFinished % 4]
+            self.prevailing = name == Wind.all4[roundsFinished % 4]
         self.setBrush(ROUNDWINDCOLOR if self.prevailing else QColor('white'))
-        windtilenr = {'N':1, 'S':2, 'E':3, 'W':4}
-        self.face.setElementId('WIND_%d' % windtilenr[name])
+        self.face.setElementId(name.svgName)
+
 
 class WindLabel(QLabel):
+
     """QLabel holding the wind tile"""
 
     @property
@@ -132,7 +141,7 @@ class WindLabel(QLabel):
         QLabel.__init__(self, parent)
         self.__wind = None
         if wind is None:
-            wind = 'E'
+            wind = East
         self.__roundsFinished = roundsFinished
         self.wind = wind
 
@@ -152,13 +161,18 @@ class WindLabel(QLabel):
         """update pixmaps"""
         PlayerWind.genWINDPIXMAPS()
         self.setPixmap(WINDPIXMAPS[(self.__wind,
-            self.__wind == WINDS[min(self.__roundsFinished, 3)])])
+                                    self.__wind == Wind.all4[min(self.__roundsFinished, 3)])])
+
 
 class Board(QGraphicsRectItem):
+
     """ a board with any number of positioned tiles"""
     # pylint: disable=too-many-instance-attributes
 
+    penColor = 'black'
+
     arrows = [Qt.Key_Left, Qt.Key_Down, Qt.Key_Up, Qt.Key_Right]
+
     def __init__(self, width, height, tileset, boardRotation=0):
         QGraphicsRectItem.__init__(self)
         self.uiTiles = []
@@ -176,13 +190,12 @@ class Board(QGraphicsRectItem):
         self.__fixedWidth = width
         self.__fixedHeight = height
         self._tileset = None
-        self._showShadows = None
         self.tileset = tileset
         self.level = 0
-        self.showShadows = Internal.Preferences.showShadows
+        Internal.Preferences.addWatch('showShadows', self.showShadowsChanged)
 
     @property
-    def name(self): # pylint: disable=no-self-use
+    def name(self):  # pylint: disable=no-self-use
         """default board name, used for debugging messages"""
         return 'board'
 
@@ -208,7 +221,8 @@ class Board(QGraphicsRectItem):
         if focusCandidates:
             firstCandidate = focusCandidates[0]
             if self._focusTile not in focusCandidates:
-                focusCandidates = list(x for x in focusCandidates if x.sortKey() >= self.__prevPos)
+                focusCandidates = list(
+                    x for x in focusCandidates if x.sortKey() >= self.__prevPos)
                 focusCandidates.append(firstCandidate)
                 self.focusTile = focusCandidates[0]
 
@@ -236,7 +250,7 @@ class Board(QGraphicsRectItem):
             self.__prevPos = uiTile.sortKey()
         self._focusTile = uiTile
         if self._focusTile and self._focusTile.tile in Debug.focusable:
-            logDebug('%s: new focus uiTile %s from %s' % (
+            logDebug(u'%s: new focus uiTile %s from %s' % (
                 self.name, self._focusTile.tile if self._focusTile else 'None', stack('')[-1]))
         if self.hasFocus:
             self.scene().focusBoard = self
@@ -269,7 +283,8 @@ class Board(QGraphicsRectItem):
             if isAlive(scene):
                 if scene.focusBoard == self or value:
                     if self.focusTile:
-                        assert self.focusTile.board == self, '%s not in self %s' % (self.focusTile, self)
+                        assert self.focusTile.board == self, '%s not in self %s' % (
+                            self.focusTile, self)
                 if value:
                     scene.focusBoard = self
 
@@ -279,7 +294,9 @@ class Board(QGraphicsRectItem):
         key = event.key()
         if key in Board.arrows:
             return key
-        charArrows = m18nc('kajongg:arrow keys hjkl like in konqueror', 'hjklHJKL')
+        charArrows = m18nc(
+            'kajongg:arrow keys hjkl like in konqueror',
+            'hjklHJKL')
         key = unicode(event.text())
         if key and key in charArrows:
             key = Board.arrows[charArrows.index(key) % 4]
@@ -301,22 +318,24 @@ class Board(QGraphicsRectItem):
             # has no focusable tiles. Like after declaring
             # Original Call.
             oldPos = self.focusTile.xoffset, self.focusTile.yoffset
-            tiles = list(x for x in tiles if (x.xoffset, x.yoffset) != oldPos or x == self.focusTile)
+            tiles = list(
+                x for x in tiles if (x.xoffset,
+                                     x.yoffset) != oldPos or x == self.focusTile)
             assert tiles, [str(x) for x in self.uiTiles]
             tiles.append(tiles[0])
-            self.focusTile = tiles[tiles.index(self.focusTile)+1]
+            self.focusTile = tiles[tiles.index(self.focusTile) + 1]
 
-    def mapMouseTile(self, uiTile): # pylint: disable=no-self-use
+    def mapMouseTile(self, uiTile):  # pylint: disable=no-self-use
         """map the pressed tile to the wanted tile. For melds, this would
         be the first tile no matter which one is pressed"""
         return uiTile
 
-    def uiMeldWithTile(self, uiTile): # pylint: disable=no-self-use
+    def uiMeldWithTile(self, uiTile):  # pylint: disable=no-self-use
         """returns the UI Meld with uiTile. A Board does not know about melds,
         so default is to return a Meld with only uiTile"""
         return Meld(uiTile)
 
-    def meldVariants(self, uiTile, lowerHalf): # pylint: disable=no-self-use,unused-argument
+    def meldVariants(self, uiTile, lowerHalf):  # pylint: disable=no-self-use,unused-argument
         """all possible melds that could be meant by dragging/dropping uiTile"""
         return [Meld(uiTile)]
 
@@ -329,25 +348,23 @@ class Board(QGraphicsRectItem):
             menu = QMenu(m18n('Choose from'))
             for idx, variant in enumerate(variants):
                 action = menu.addAction(variant.typeName())
-                action.setData(QVariant(idx))
+                action.setData(toQVariant(idx))
             if Internal.scene.mainWindow.centralView.dragObject:
                 menuPoint = QCursor.pos()
             else:
                 menuPoint = uiTile.board.tileFaceRect().bottomRight()
                 view = Internal.scene.mainWindow.centralView
-                menuPoint = view.mapToGlobal(view.mapFromScene(uiTile.mapToScene(menuPoint)))
+                menuPoint = view.mapToGlobal(
+                    view.mapFromScene(uiTile.mapToScene(menuPoint)))
             action = menu.exec_(menuPoint)
             if not action:
                 return None
-            if usingQt5:
-                idx = action.data() # autoconvert
-            else:
-                idx = action.data().toInt()[0]
+            idx = variantValue(action.data())
         return variants[idx]
 
     def dragEnterEvent(self, dummyEvent):
         """drag enters the HandBoard: highlight it"""
-        self.setPen(QPen(QColor('blue')))
+        self.setPen(QPen(QColor(self.penColor)))
 
     def dragLeaveEvent(self, dummyEvent):
         """drag leaves the HandBoard"""
@@ -355,7 +372,10 @@ class Board(QGraphicsRectItem):
 
     def _noPen(self):
         """remove pen for this board. The pen defines the border"""
-        self.setPen(QPen(Qt.NoPen))
+        if Debug.graphics:
+            self.setPen(QPen(QColor(self.penColor)))
+        else:
+            self.setPen(QPen(Qt.NoPen))
 
     def tileAt(self, xoffset, yoffset, level=0):
         """if there is a uiTile at this place, return it"""
@@ -370,12 +390,12 @@ class Board(QGraphicsRectItem):
     def rotatedLightSource(self):
         """the light source we need for the original uiTile before it is rotated"""
         lightSourceIndex = LIGHTSOURCES.index(self.lightSource)
-        lightSourceIndex = (lightSourceIndex+self.sceneRotation() // 90)%4
+        lightSourceIndex = (lightSourceIndex + self.sceneRotation() // 90) % 4
         return LIGHTSOURCES[lightSourceIndex]
 
     def tileFacePos(self):
         """the face pos of a uiTile relative to its origin"""
-        if not self.showShadows:
+        if not Internal.Preferences.showShadows:
             return QPointF()
         lightSource = self.rotatedLightSource()
         xoffset = self.tileset.shadowWidth() - 1 if 'E' in lightSource else 0
@@ -389,8 +409,13 @@ class Board(QGraphicsRectItem):
     def sceneRotation(self):
         """the combined rotation of self and all parents"""
         matrix = self.sceneTransform()
-        matrix = (int(matrix.m11()), int(matrix.m12()), int(matrix.m21()), int(matrix.m22()))
-        rotations = {(0, 0, 0, 0):0, (1, 0, 0, 1):0, (0, 1, -1, 0):90, (-1, 0, 0, -1):180, (0, -1, 1, 0):270}
+        matrix = (
+            int(matrix.m11()),
+            int(matrix.m12()),
+            int(matrix.m21()),
+            int(matrix.m22()))
+        rotations = {(0, 0, 0, 0): 0, (1, 0, 0, 1): 0, (
+            0, 1, -1, 0): 90, (-1, 0, 0, -1): 180, (0, -1, 1, 0): 270}
         if matrix not in rotations:
             raise Exception('matrix unknown:%s' % str(matrix))
         return rotations[matrix]
@@ -414,8 +439,9 @@ class Board(QGraphicsRectItem):
         """translate from our rect coordinates to scene coord"""
         sizeX = self.tileset.faceSize.width() * self.__fixedWidth
         sizeY = self.tileset.faceSize.height() * self.__fixedHeight
-        if self.showShadows:
-            sizeX += self.tileset.shadowWidth() + 2 * self.tileset.shadowHeight()
+        if Internal.Preferences.showShadows:
+            sizeX += self.tileset.shadowWidth() + \
+                2 * self.tileset.shadowHeight()
             sizeY += self.tileset.shadowHeight()
         rect = self.rect()
         rect.setWidth(sizeX)
@@ -439,28 +465,23 @@ class Board(QGraphicsRectItem):
         This is also called when the tileset or the light source for this board changes"""
         width = self.tileset.faceSize.width()
         height = self.tileset.faceSize.height()
-        if not self.showShadows:
+        if not Internal.Preferences.showShadows:
             offsets = (0, 0)
         elif self.isHandBoard:
             offsets = (-self.tileset.shadowHeight() * 2, 0)
         else:
-            offsets = self.tileset.shadowOffsets(self._lightSource, self.sceneRotation())
-        newX = self.__xWidth*width+self.__xHeight*height + offsets[0]
-        newY = self.__yWidth*width+self.__yHeight*height + offsets[1]
+            offsets = self.tileset.shadowOffsets(
+                self._lightSource,
+                self.sceneRotation())
+        newX = self.__xWidth * width + self.__xHeight * height + offsets[0]
+        newY = self.__yWidth * width + self.__yHeight * height + offsets[1]
         QGraphicsRectItem.setPos(self, newX, newY)
 
-    @property
-    def showShadows(self):
-        """the active lightSource"""
-        return self._showShadows
-
-    @showShadows.setter
-    def showShadows(self, value):
+    def showShadowsChanged(self, dummyOldValue, newValue):
         """set active lightSource"""
-        if self._showShadows != value:
-            for uiTile in self.uiTiles:
-                uiTile.setClippingFlags()
-            self._reload(self.tileset, showShadows=value)
+        for uiTile in self.uiTiles:
+            uiTile.setClippingFlags()
+        self._reload(self.tileset, showShadows=newValue)
 
     @property
     def lightSource(self):
@@ -472,7 +493,10 @@ class Board(QGraphicsRectItem):
         """set active lightSource"""
         if self._lightSource != lightSource:
             if lightSource not in LIGHTSOURCES:
-                logException(TileException('lightSource %s illegal' % lightSource))
+                logException(
+                    TileException(
+                        'lightSource %s illegal' %
+                        lightSource))
             self._reload(self.tileset, lightSource)
 
     @property
@@ -492,12 +516,13 @@ class Board(QGraphicsRectItem):
         if lightSource is None:
             lightSource = self._lightSource
         if showShadows is None:
-            showShadows = self._showShadows
-        if self._tileset != tileset or self._lightSource != lightSource or self._showShadows != showShadows:
+            showShadows = Internal.Preferences.showShadows
+        if (self._tileset != tileset
+                or self._lightSource != lightSource
+                or Internal.Preferences.showShadows != showShadows):
             self.prepareGeometryChange()
             self._tileset = tileset
             self._lightSource = lightSource
-            self._showShadows = showShadows
             self.setGeometry()
             for child in self.childItems():
                 if isinstance(child, (Board, PlayerWind)):
@@ -511,7 +536,7 @@ class Board(QGraphicsRectItem):
             if self.hasFocus:
                 self.scene().focusBoard = self
 
-    def focusRectWidth(self): # pylint: disable=no-self-use
+    def focusRectWidth(self):  # pylint: disable=no-self-use
         """how many tiles are in focus rect?"""
         return 1
 
@@ -520,14 +545,14 @@ class Board(QGraphicsRectItem):
         level is the vertical position. 0 is the face position on
         ground level, -1 is the imprint a uiTile makes on the
         surface it stands on"""
-        if not self.showShadows:
+        if not Internal.Preferences.showShadows:
             return QPointF()
         shiftX = 0
         shiftY = 0
         if level != 0:
             lightSource = self.rotatedLightSource()
-            stepX = level*self.tileset.shadowWidth()/2
-            stepY = level*self.tileset.shadowHeight()/2
+            stepX = level * self.tileset.shadowWidth() / 2
+            stepY = level * self.tileset.shadowHeight() / 2
             if 'E' in lightSource:
                 shiftX = stepX
             if 'W' in lightSource:
@@ -555,7 +580,9 @@ class Board(QGraphicsRectItem):
         width = self.tileset.faceSize.width()
         height = self.tileset.faceSize.height()
         shiftZ = self.shiftZ(uiTile.level)
-        boardPos = QPointF(uiTile.xoffset*width, uiTile.yoffset*height) + shiftZ
+        boardPos = QPointF(
+            uiTile.xoffset * width,
+            uiTile.yoffset * height) + shiftZ
         scenePos = self.mapToScene(boardPos)
         uiTile.setDrawingOrder()
         return {'pos': scenePos, 'rotation': self.sceneRotation(), 'scale': self.scale()}
@@ -590,10 +617,14 @@ class Board(QGraphicsRectItem):
         if self.currentFocusTile == uiTile:
             self.focusTile = None
 
+
 class CourtBoard(Board):
+
     """A Board that is displayed within the wall"""
+    penColor = 'green'
+
     def __init__(self, width, height):
-        Board.__init__(self, width, height, Internal.scene.tileset)
+        Board.__init__(self, width, height, Tileset.activeTileset())
         self.setAcceptDrops(True)
 
     def maximize(self):
@@ -606,7 +637,7 @@ class CourtBoard(Board):
         yAvail = cWall[0].sceneBoundingRect().top() - newSceneY
         shadowHeight = tileset.shadowHeight()
         shadowWidth = tileset.shadowWidth()
-        if self.showShadows:
+        if Internal.Preferences.showShadows:
             # this should use the real shadow values from the wall because the wall
             # tiles are smaller than those in the CourtBoard but this should be
             # good enough
@@ -619,13 +650,16 @@ class CourtBoard(Board):
         xScaleFactor = xAvail / xNeeded
         yScaleFactor = yAvail / yNeeded
         QGraphicsRectItem.setPos(self, newSceneX, newSceneY)
-        Board.setScale(self, min(xScaleFactor, yScaleFactor))
+        self.setScale(min(xScaleFactor, yScaleFactor))
         for uiTile in self.uiTiles:
             uiTile.board.placeTile(uiTile)
 
+
 class SelectorBoard(CourtBoard):
+
     """a board containing all possible tiles for selection"""
     # pylint: disable=too-many-public-methods
+
     def __init__(self):
         CourtBoard.__init__(self, 9, 5)
         self.lastReceived = None
@@ -640,12 +674,13 @@ class SelectorBoard(CourtBoard):
         for uiTile in self.uiTiles:
             uiTile.setBoard(None)
         self.uiTiles = []
-        self.allSelectorTiles = list(UITile(x) for x in elements.all(game.ruleset))
+        self.allSelectorTiles = list(UITile(x)
+                                     for x in elements.all(game.ruleset))
         self.refill()
 
     def refill(self):
         """move all tiles back into the selector"""
-        with Animated(False):
+        with MoveImmediate():
             for uiTile in self.allSelectorTiles:
                 uiTile.tile = uiTile.tile.exposed
                 self.__placeAvailable(uiTile)
@@ -654,7 +689,7 @@ class SelectorBoard(CourtBoard):
             self.focusTile = self.tilesByElement(Tile('c1'))[0]
 
     @property
-    def name(self): # pylint: disable=no-self-use
+    def name(self):  # pylint: disable=no-self-use
         """for debugging messages"""
         return 'selector'
 
@@ -669,7 +704,7 @@ class SelectorBoard(CourtBoard):
         self.dropTile(uiTile)
         event.accept()
 
-    def dropTile(self, uiTile, lowerHalf=False): # pylint: disable=unused-argument
+    def dropTile(self, uiTile, lowerHalf=False):  # pylint: disable=unused-argument
         """drop uiTile into selector board"""
         senderHand = uiTile.board
         if senderHand == self:
@@ -689,7 +724,9 @@ class SelectorBoard(CourtBoard):
         assert isinstance(uiTile, UITile), uiTile
         result = UIMeld(uiTile)
         for tile in meld[1:]:
-            baseTiles = list(x for x in self.tilesByElement(tile.exposed) if x not in result)
+            baseTiles = list(
+                x for x in self.tilesByElement(
+                    tile.exposed) if x not in result)
             result.append(baseTiles[0])
         return result
 
@@ -699,11 +736,13 @@ class SelectorBoard(CourtBoard):
     def __placeAvailable(self, uiTile):
         """place the uiTile in the selector at its place"""
         # define coordinates and order for tiles:
-        offsets = {Tile.dragon: (3, 6, Tile.dragons), Tile.flower: (4, 5, Tile.winds), Tile.season: (4, 0, Tile.winds),
-            Tile.wind: (3, 0, Tile.winds), Tile.bamboo: (1, 0, Tile.numbers), Tile.stone: (2, 0, Tile.numbers),
-            Tile.character: (0, 0, Tile.numbers)}
+        offsets = {Tile.dragon: (
+            3, 6, Tile.dragons), Tile.flower: (
+                4, 5, Tile.winds), Tile.season: (4, 0, Tile.winds),
+                   Tile.wind: (3, 0, Tile.winds), Tile.bamboo: (1, 0, Tile.numbers), Tile.stone: (2, 0, Tile.numbers),
+                   Tile.character: (0, 0, Tile.numbers)}
         row, baseColumn, order = offsets[uiTile.tile.lowerGroup]
-        column = baseColumn + order.index(uiTile.tile.value)
+        column = baseColumn + order.index(uiTile.tile.char)
         uiTile.dark = False
         uiTile.setBoard(self, column, row)
 
@@ -732,9 +771,7 @@ class SelectorBoard(CourtBoard):
             else:
                 result.append(lowerName.kong)
                 result.append(lowerName.kong.exposedClaimed)
-        # TODO: old bug: move 3 identical hidden chows to east, then move
-        # one of them to south exposed
-        if not wantedTile.isHonor and wantedTile.value < 8:
+        if wantedTile.isNumber and wantedTile.value < 8:
             chow2 = scName.nextForChow
             chow3 = chow2.nextForChow
             if self.tilesByElement(chow2.exposed) and self.tilesByElement(chow3.exposed):
@@ -742,15 +779,21 @@ class SelectorBoard(CourtBoard):
         # result now holds a list of melds
         return result
 
+
 class MimeData(QMimeData):
+
     """we also want to pass a reference to the moved meld"""
+
     def __init__(self, uiTile):
         QMimeData.__init__(self)
         self.uiTile = uiTile
         self.setText(str(uiTile))
 
+
 class FittingView(QGraphicsView):
+
     """a graphics view that always makes sure the whole scene is visible"""
+
     def __init__(self, parent=None):
         """generate a fitting view with our favourite properties"""
         QGraphicsView.__init__(self, parent)
@@ -772,23 +815,19 @@ class FittingView(QGraphicsView):
         """we do not want scrolling for the scene view.
         Instead scrolling down changes perspective like in kmahjongg"""
         if event.orientation() == Qt.Vertical and event.delta() < 0:
-            Internal.scene.changeAngle()
+            Internal.mainWindow.changeAngle()
         # otherwise do not call ignore() because we do want
         # to consume this
 
     def resizeEvent(self, dummyEvent):
-        """scale the scene for new view size"""
-        # also adjust the background to the container. Do this here because this way
-        # it is easier to minimize calls to setBackground()
-        parent = self.parentWidget()
-        if parent:
-            grandpa = parent.parentWidget()
-            if grandpa and grandpa.objectName() == 'MainWindow':
-                grandpa.applySettings()
-                # resize background:
-                grandpa.backgroundName = grandpa.backgroundName
+        """scale the scene and its background for new view size"""
+        Internal.Preferences.callTrigger(
+            'tilesetName')  # this redraws and resizes
+        Internal.Preferences.callTrigger('backgroundName')  # redraw background
         if Internal.scaleScene and self.scene():
-            self.fitInView(self.scene().itemsBoundingRect(), Qt.KeepAspectRatio)
+            self.fitInView(
+                self.scene().itemsBoundingRect(),
+                Qt.KeepAspectRatio)
         self.setFocus()
 
     def __matchingTile(self, position, uiTile):
@@ -819,7 +858,9 @@ class FittingView(QGraphicsView):
         if tiles:
             if event.modifiers() & Qt.ShiftModifier:
                 for uiTile in tiles:
-                    kprint('%s: board.level:%s' % (str(uiTile), uiTile.board.level))
+                    kprint(
+                        '%s: board.level:%s' %
+                        (str(uiTile), uiTile.board.level))
             board = tiles[0].board
             uiTile = board.mapMouseTile(tiles[0])
             if uiTile.focusable:
@@ -860,14 +901,19 @@ class FittingView(QGraphicsView):
         drag.setMimeData(mimeData)
         tRect = uiTile.boundingRect()
         tRect = self.viewportTransform().mapRect(tRect)
-        pmapSize = QSize(tRect.width() * uiTile.scale, tRect.height() * uiTile.scale)
+        pmapSize = QSize(
+            tRect.width() * uiTile.scale,
+            tRect.height() * uiTile.scale)
         pMap = uiTile.pixmapFromSvg(pmapSize)
         drag.setPixmap(pMap)
-        drag.setHotSpot(QPoint(pMap.width()/2, pMap.height()/2))
+        drag.setHotSpot(QPoint(pMap.width() / 2, pMap.height() / 2))
         return drag
 
+
 class YellowText(QGraphicsRectItem):
+
     """a yellow rect with a message, used for claims"""
+
     def __init__(self, side):
         QGraphicsRectItem.__init__(self, side)
         self.side = side
@@ -889,28 +935,33 @@ class YellowText(QGraphicsRectItem):
         self.setPos(self.side.center())
         rotation = self.side.rotation()
         rotateCenter(self, -rotation)
-        xOffset = -self.rect().width()/2
-        yOffset = -self.rect().height()/2
+        xOffset = -self.rect().width() / 2
+        yOffset = -self.rect().height() / 2
         if rotation % 180 == 0:
             self.moveBy(xOffset, yOffset * 4)
         else:
             self.moveBy(xOffset, yOffset)
+
     def paint(self, painter, dummyOption, dummyWidget):
         """override predefined paint"""
         painter.setFont(self.font)
         painter.fillRect(self.rect(), QBrush(QColor('yellow')))
         painter.drawText(self.rect(), self.msg)
 
+
 class DiscardBoard(CourtBoard):
+
     """A special board for discarded tiles"""
     # pylint: disable=too-many-public-methods
+    penColor = 'orange'
+
     def __init__(self):
         CourtBoard.__init__(self, 11, 9)
         self.__places = None
         self.lastDiscarded = None
 
     @property
-    def name(self): # pylint: disable=no-self-use
+    def name(self):  # pylint: disable=no-self-use
         """to be used in debug output"""
         return "discardBoard"
 
@@ -921,7 +972,8 @@ class DiscardBoard(CourtBoard):
 
     def setRandomPlaces(self, randomGenerator):
         """precompute random positions"""
-        self.__places = [(x, y) for x in range(self.width) for y in range(self.height)]
+        self.__places = [(x, y) for x in range(self.width)
+                         for y in range(self.height)]
         randomGenerator.shuffle(self.__places)
 
     def discardTile(self, uiTile):
@@ -936,8 +988,6 @@ class DiscardBoard(CourtBoard):
 
     def dropEvent(self, event):
         """drop a uiTile into the discard board"""
-        # TODO: now that tiles are top level scene items, maybe drag them
-        # directly. Draggings melds: QGraphicsItemGroup?
         uiTile = event.mimeData().uiTile
         assert isinstance(uiTile, UITile), uiTile
         uiTile.setPos(event.scenePos() - uiTile.boundingRect().center())
