@@ -24,12 +24,6 @@ python interface to KDE.
 
 """
 
-__all__ = ['KAboutData', 'KApplication', 'KCmdLineArgs', 'KConfig',
-           'KCmdLineOptions', 'i18n', 'i18nc', 'ki18n',
-           'KMessageBox', 'KConfigSkeleton', 'KDialogButtonBox',
-           'KConfigDialog', 'KDialog', 'KLineEdit',
-           'KUser', 'KToggleFullScreenAction', 'KStandardAction',
-           'KXmlGuiWindow', 'KStandardDirs', 'KGlobal', 'KIcon', 'KAction']
 
 import sys
 import os
@@ -42,9 +36,13 @@ if os.name != 'nt':
 import weakref
 from collections import defaultdict
 from argparse import ArgumentParser
+from locale import _parse_localename, getdefaultlocale, setlocale, LC_ALL
+
 
 import sip
 
+# pylint: disable=wrong-import-order
+
 try:
     from ConfigParser import SafeConfigParser, NoSectionError, NoOptionError
 except ImportError:
@@ -52,20 +50,26 @@ except ImportError:
     # pylint: disable=import-error
     from configparser import SafeConfigParser, NoSectionError, NoOptionError
 
-from locale import _parse_localename, getdefaultlocale, setlocale, LC_ALL
-
 # here come the replacements:
 
 # pylint: disable=wildcard-import,unused-wildcard-import
 from qt import *
 
-from common import Internal, Debug, ENGLISHDICT, unicodeString
+from common import Internal, Debug, ENGLISHDICT, unicodeString, isPython3
 from util import uniqueList
 from statesaver import StateSaver
 
 import gettext
 
 
+__all__ = ['KAboutData', 'KApplication', 'KCmdLineArgs', 'KConfig',
+           'KCmdLineOptions', 'i18n', 'i18nc', 'ki18n',
+           'KMessageBox', 'KConfigSkeleton', 'KDialogButtonBox',
+           'KConfigDialog', 'KDialog', 'KLineEdit',
+           'KUser', 'KToggleFullScreenAction', 'KStandardAction',
+           'KXmlGuiWindow', 'KStandardDirs', 'KGlobal', 'KIcon', 'KAction']
+
+
 def __insertArgs(translatedTemplate, *args):
     """
     put format arguments into the translated template.
@@ -79,8 +83,6 @@ def __insertArgs(translatedTemplate, *args):
     @return: The formatted translated text.
     @rtype: C{str}
     """
-    if '@' in translatedTemplate:
-        Internal.logger.debug('insertargs:%s' % translatedTemplate)
 
     if '\004' in translatedTemplate:
         translatedTemplate = translatedTemplate.split('\004')[1]
@@ -106,7 +108,7 @@ def i18n(englishIn, *args):
     @rtype: C{unicode}
     """
     assert englishIn
-    if KGlobal.translation and englishIn:
+    if not Debug.neutral and KGlobal.translation and englishIn:
         _ = KGlobal.translation.gettext(englishIn)
     else:
         _ = englishIn
@@ -625,10 +627,10 @@ class KXmlGuiWindow(CaptionMixin, QMainWindow):
         self.statusBar().setObjectName('StatusBar')
         self.menus = {}
         for menu in (
-            (i18n('&Game'), ('scoreGame', 'play', 'abort', 'quit')),
-            (i18n('&View'), ('scoreTable', 'explain')),
-            (i18n('&Settings'), ('players', 'rulesets', 'demoMode', '', 'options_show_statusbar',
-                                 'options_show_toolbar', '', 'options_configure_toolbars', 'options_configure')),
+                (i18n('&Game'), ('scoreGame', 'play', 'abort', 'quit')),
+                (i18n('&View'), ('scoreTable', 'explain')),
+                (i18n('&Settings'), ('players', 'rulesets', 'demoMode', '', 'options_show_statusbar',
+                                     'options_show_toolbar', '', 'options_configure_toolbars', 'options_configure')),
                 (i18n('&Help'), ('help', 'aboutkajongg'))):
             self.menus[menu[0]] = (QMenu(menu[0]), menu[1])
             self.menuBar().addMenu(self.menus[menu[0]][0])
@@ -753,10 +755,19 @@ class KStandardDirs(object):
                     dirMap[key] = list(os.path.normpath(x)
                                        for x in dirMap[key])
             else:
-                KStandardDirs.prefix = subprocess.Popen(
-                    ['which', 'kde4-config'],
-                    stdout=subprocess.PIPE).communicate()[0].split(b'/')[1].decode('utf-8')  # TODO: fsencoding
-                KStandardDirs.prefix = '/%s/' % KStandardDirs.prefix
+                kde4configPath = self.which('kde4-config')
+                if kde4configPath:
+                    KStandardDirs.prefix = '/{}/'.format(
+                        kde4configPath.split(b'/')[1].decode('utf-8'))
+                else:
+                    raise Exception('Cannot find kde4-config')
+
+    @staticmethod
+    def which(program):
+        """calls which program"""
+        return subprocess.Popen(
+            ['which', program],
+            stdout=subprocess.PIPE).communicate()[0]
 
     @classmethod
     def kde_default(cls, type_):
@@ -772,9 +783,9 @@ class KStandardDirs(object):
         exists = os.path.exists(tryThis)
         if Debug.locate:
             if exists:
-                Internal.logger.debug('found: %s' % tryThis)
+                Internal.logger.debug('found: %s', tryThis)
             else:
-                Internal.logger.debug('not found: %s' % tryThis)
+                Internal.logger.debug('not found: %s', tryThis)
         return exists, tryThis
 
     @classmethod
@@ -803,8 +814,9 @@ class KStandardDirs(object):
                     fullPath)
             os.makedirs(os.path.dirname(fullPath))
         if Debug.locate:
-            Internal.logger.debug('locateLocal(%s, %s) returns %s' % (
-                type_, filename, fullPath))
+            Internal.logger.debug(
+                'locateLocal(%s, %s) returns %s',
+                type_, filename, fullPath)
         return fullPath
 
     @classmethod
@@ -861,8 +873,8 @@ class KStandardDirs(object):
         result = cls.findDirs(type_, filename)
         if Debug.locate:
             Internal.logger.debug(
-                'findResourceDir(%s,%s) finds %s' %
-                (type_, filename, result))
+                'findResourceDir(%s,%s) finds %s',
+                type_, filename, result)
         return result
 
 
@@ -906,6 +918,12 @@ class KLocale(object):
         translator = KDETranslator(app)
         QCoreApplication.installTranslator(translator)
 
+    @staticmethod
+    def setLanguage(lang):
+        """stub"""
+        assert lang == 'en_US', 'KLocale.setLanguage currently only supports en_US'
+        QCoreApplication.installTranslator(None)
+
 
 class KConfigGroup(object):
 
@@ -1059,8 +1077,11 @@ class KConfig(SafeConfigParser):
             path = KGlobal.dirs().locateLocal("config", "kajonggrc")
         self.path = str(path)
         if os.path.exists(self.path):
-            with codecs.open(self.path, 'rb', encoding='utf-8') as cfgFile:
-                self.readfp(cfgFile)
+            with codecs.open(self.path, 'r', encoding='utf-8') as cfgFile:
+                if isPython3:
+                    self.read_file(cfgFile)
+                else:
+                    self.readfp(cfgFile) # pylint: disable=deprecated-method
 
     def as_dict(self):
         """a dict of dicts"""
@@ -1088,9 +1109,9 @@ class KConfig(SafeConfigParser):
             for section in self._sections:
                 filePointer.write(("[%s]\n" % section).encode('utf-8'))
                 for (key, value) in self._sections[section].items():
-                    key = str(key).encode('utf-8')
+                    key = bytes(str(key).encode('utf-8')) # pylint bug, bytes() should not be needed
                     value = str(value).encode('utf-8')
-                    if key == "__name__":
+                    if key == b"__name__":
                         continue
                     if value is not None:
                         key = b"=".join((key, value.replace(b'\n', b'\n\t')))
@@ -1125,7 +1146,7 @@ class KIcon(QIcon):
                     name,
                     extension))
             if not os.path.exists(name):
-                Internal.logger.debug('not found:%s' % name)
+                Internal.logger.debug('not found:%s', name)
                 raise UserWarning('not found:%s' % name)
             QIcon.__init__(self, name)
             return
@@ -1334,15 +1355,15 @@ class AboutKajonggDialog(KDialog):
         hLayout1.addWidget(IconLabel('kajongg', self))
         h1vLayout = QVBoxLayout()
         h1vLayout.addWidget(QLabel('Kajongg'))
-        h1vLayout.addWidget(QLabel(i18n('Version %1', Internal.version)))
+        h1vLayout.addWidget(QLabel(i18n('Protocol version %1', Internal.defaultPort)))
         underVersions = []
         try:
             versions = subprocess.Popen(['kde4-config', '-v'],
                                         stdout=subprocess.PIPE).communicate()[0]
             versions = versions.decode().split('\n')
             versions = (x.strip() for x in versions if ': ' in x.strip())
-            versions = dict(x.split(': ') for x in versions)
-            underVersions.append('KDE %s' % versions['KDE'])
+            versionsDict = dict(x.split(': ') for x in versions)
+            underVersions.append('KDE %s' % versionsDict['KDE'])
         except OSError:
             underVersions.append(i18n('KDE (not installed)'))
         underVersions.append('Qt %s' % QT_VERSION_STR)
@@ -1462,12 +1483,12 @@ class KConfigDialog(KDialog):
     dialog = None
     getFunc = {
         'QCheckBox': 'isChecked',
-            'QSlider': 'value',
-            'QLineEdit': 'text'}
+        'QSlider': 'value',
+        'QLineEdit': 'text'}
     setFunc = {
         'QCheckBox': 'setChecked',
-            'QSlider': 'setValue',
-            'QLineEdit': 'setText'}
+        'QSlider': 'setValue',
+        'QLineEdit': 'setText'}
 
     def __init__(self, parent, name, preferences):
         KDialog.__init__(self, parent)
@@ -1562,14 +1583,14 @@ class KConfigDialog(KDialog):
 
     def applySettings(self):
         """Apply pressed"""
-        changed = self.updateButtons()
-        self.updateSettings()
-        self.updateButtons()
+        if self.updateButtons():
+            self.updateSettings()
+            self.updateButtons()
 
     def accept(self):
         """OK pressed"""
-        changed = self.updateButtons()
-        self.updateSettings()
+        if self.updateButtons():
+            self.updateSettings()
         KDialog.accept(self)
 
     def updateButtons(self):
